==> miro_4.0.4.orig.tar.gz: miro-4.0.4/windows/plat/frontends/widgets/XULRunnerBrowser/MiroWindowCreator.h <==
/*
# Miro - an RSS based video player application
# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
# Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.
*/

#ifndef __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__
#define __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__

#include <Python.h>
#include "nsIWindowCreator.h"
#include "embed_base/nsIWindowCreator2.h"
#include "nsEmbedString.h"

typedef void(*windowCallback)(char* uri, void* data);

class MiroWindowCreator : public nsIWindowCreator2
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIWINDOWCREATOR
  NS_DECL_NSIWINDOWCREATOR2

  MiroWindowCreator();

  // Install the WindowCreator
  nsresult install();
  // Set the window callback.  This will be called when XULRunner wants to
  // open a new window .
  void SetNewWindowCallback(windowCallback callback, void* data);

private:
  ~MiroWindowCreator();

protected:
    windowCallback mWindowCallback;
    void* mWindowCallbackData;
};


#endif /* __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__ */

==> miro_6.0.orig.tar.gz: miro-6.0/windows/plat/frontends/widgets/XULRunnerBrowser/MiroWindowCreator.h <==
/*
# Miro - an RSS based video player application
# Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011
# Participatory Culture Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
#
# In addition, as a special exception, the copyright holders give
# permission to link the code of portions of this program with the OpenSSL
# library.
#
# You must obey the GNU General Public License in all respects for all of
# the code used other than OpenSSL. If you modify file(s) with this
# exception, you may extend this exception to your version of the file(s),
# but you are not obligated to do so. If you do not wish to do so, delete
# this exception statement from your version. If you delete this exception
# statement from all source files in the program, then also delete it here.
*/

#ifndef __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__
#define __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__

#include <Python.h>
#include "nsIWindowCreator.h"
#include "nsIWindowCreator2.h"
#include "nsEmbedString.h"

typedef void(*windowCallback)(char* uri, void* data);

class MiroWindowCreator : public nsIWindowCreator2
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIWINDOWCREATOR
  NS_DECL_NSIWINDOWCREATOR2

  MiroWindowCreator();

  // Install the WindowCreator
  nsresult install();
  // Set the window callback.  This will be called when XULRunner wants to
  // open a new window .
  void SetNewWindowCallback(windowCallback callback, void* data);

private:
  ~MiroWindowCreator();

protected:
    windowCallback mWindowCallback;
    void* mWindowCallbackData;
};


#endif /* __PCF_XULRUNNER_MIRO_WINDOW_CREATOR_H__ */
